@@ -67,7 +67,7 @@ int BuildGSMTime(PyObject *pydt, GSM_DateTime *dt);
 /**
  * Convert Python unicode string to Gammu unicode string.
  */
-unsigned char *strPythonToGammu(const Py_UNICODE *src);
+unsigned char *strPythonToGammu(const Py_UNICODE *src, const size_t len);
 
 /**
  * Converts either object to unicode and returns its value.
@@ -134,6 +134,11 @@ int GetIntFromDict(PyObject *dict, char *key);
  */
 bool GetBoolFromDict(PyObject *dict, char *key);
 
+/**
+ * Gets C string from dictionary dict with key key.
+ */
+char *GetCStringFromDict(PyObject *dict, char *key);
+
 /**
  * Gets gammu unicode string from dictionary dict with key key.
  */
@@ -259,6 +264,16 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry);
  */
 int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location);
 
+/**
+ * Convert calendar type to string.
+ */
+char *CalendarTypeToString(GSM_CalendarNoteType p);
+
+/**
+ * Convert string to calendar type.
+ */
+GSM_CalendarNoteType StringToCalendarType(const char *s);
+
 /**
  * Converts Calendar to Python object.
  */
@@ -335,11 +350,31 @@ PyObject *FileToPython(GSM_File *file);
 int FileFromPython(PyObject *dict, GSM_File *file, bool check);
 
 /**
- * Converst call to Python object.
+ * Converts call to Python object.
  */
 PyObject *CallToPython(GSM_Call *call);
 
 /**
- * Converst call type to Python object.
+ * Converts call type to Python object.
  */
 char *CallStatusToString(GSM_CallStatus ct);
+
+/**
+ * Converts MMS indicator to Python object.
+ */
+PyObject *MMSIndicatorToPython(GSM_MMSIndicator *mms);
+
+/**
+ * Converts MMS indicator from Python object.
+ */
+int MMSIndicatorFromPython(PyObject* dict, GSM_MMSIndicator *mms);
+
+/**
+ * Converts WAP bookmark to Python object.
+ */
+PyObject *WAPBookmarkToPython(GSM_WAPBookmark *wap);
+
+/**
+ * Converts WAP bookmark from Python object.
+ */
+int WAPBookmarkFromPython(PyObject* dict, GSM_WAPBookmark *wap);
