@@ -28,7 +28,7 @@
                     Py_DECREF(v); \
                     return NULL; \
                 } \
-                f = Py_BuildValue("{s:s,s:u}", "Type", name, "Value", s); \
+                f = Py_BuildValue("{s:s,s:u,s:i}", "Type", name, "Value", s, "AddError", (int)entry->Entries[i].AddError); \
                 free(s);
 
 #define convert_number(name) \
@@ -158,6 +158,9 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_Text_Custom4:
                 convert_text("Text_Custom4");
                 break;
+            case PBK_Text_LUID:
+                convert_text("Text_LUID");
+                break;
             case PBK_Text_UserID:
                 convert_text("Text_UserID");
                 break;
@@ -279,6 +282,13 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
             PyErr_Clear();
         }
 
+        /* Get AddError flag */
+        entry->Entries[i].AddError = GetIntFromDict(item, "AddError");
+        if (entry->Entries[i].AddError == INT_INVALID) {
+            entry->Entries[i].AddError = ERR_NONE;
+            PyErr_Clear();
+        }
+
         if (strcmp("Number_General", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Number_General;
@@ -369,6 +379,9 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Text_Custom4", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Custom4;
+        } else if (strcmp("Text_LUID", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Text_LUID;
         } else if (strcmp("Text_UserID", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_UserID;
