@@ -27,6 +27,7 @@ char *SMSValidityToString(GSM_SMSValidity Validity) {
 
     switch (Validity.Format) {
         case SMS_Validity_NotAvailable:
+        case 0:
             strcpy(s, "NA");
             break;
         case SMS_Validity_RelativeFormat:
@@ -1354,9 +1355,8 @@ PyObject *SMSPartToPython(MultiPartSMSEntry *entry) {
     }
     Py_DECREF(v);
 
-#if 0
     if (entry->Bookmark != NULL) {
-        v = BookmarkToPython(entry->Bookmark);
+        v = WAPBookmarkToPython(entry->Bookmark);
         if (v == NULL) return NULL;
     } else {
         Py_INCREF(Py_None);
@@ -1369,8 +1369,9 @@ PyObject *SMSPartToPython(MultiPartSMSEntry *entry) {
     }
     Py_DECREF(v);
 
+#if 0
     if (entry->Settings != NULL) {
-        v = SettingsToPython(entry->Settings);
+        v = WAPSettingsToPython(entry->Settings);
         if (v == NULL) return NULL;
     } else {
         Py_INCREF(Py_None);
@@ -1382,6 +1383,7 @@ PyObject *SMSPartToPython(MultiPartSMSEntry *entry) {
         return NULL;
     }
     Py_DECREF(v);
+#endif
 
     if (entry->MMSIndicator != NULL) {
         v = MMSIndicatorToPython(entry->MMSIndicator);
@@ -1396,7 +1398,6 @@ PyObject *SMSPartToPython(MultiPartSMSEntry *entry) {
         return NULL;
     }
     Py_DECREF(v);
-#endif
 
     if (entry->Phonebook != NULL) {
         v = MemoryEntryToPython(entry->Phonebook);
@@ -1622,7 +1623,6 @@ int SMSPartFromPython(PyObject *dict, MultiPartSMSEntry *entry) {
         }
     }
 
-#if 0
     o = PyDict_GetItemString(dict, "Bookmark");
     if (o != NULL && o != Py_None) {
         entry->Bookmark = (GSM_WAPBookmark *)malloc(sizeof(GSM_WAPBookmark));
@@ -1630,11 +1630,12 @@ int SMSPartFromPython(PyObject *dict, MultiPartSMSEntry *entry) {
             PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate structure");
             return 0;
         }
-        if (!BookmarkFromPython(o, entry->Bookmark)) {
+        if (!WAPBookmarkFromPython(o, entry->Bookmark)) {
             return 0;
         }
     }
 
+#if 0
     o = PyDict_GetItemString(dict, "Settings");
     if (o != NULL && o != Py_None) {
         entry->Settings = (GSM_WAPSettings *)malloc(sizeof(GSM_WAPSettings));
@@ -1646,6 +1647,7 @@ int SMSPartFromPython(PyObject *dict, MultiPartSMSEntry *entry) {
             return 0;
         }
     }
+#endif
 
     o = PyDict_GetItemString(dict, "MMSIndicator");
     if (o != NULL && o != Py_None) {
@@ -1658,7 +1660,6 @@ int SMSPartFromPython(PyObject *dict, MultiPartSMSEntry *entry) {
             return 0;
         }
     }
-#endif
 
     o = PyDict_GetItemString(dict, "Phonebook");
     if (o != NULL && o != Py_None) {
