@@ -63,6 +63,7 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry) {
     int         i;
     Py_UNICODE  *s;
     char        *p;
+    char        *t;
 
     v = PyList_New(0);
     if (v == NULL) return NULL;
@@ -106,6 +107,33 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry) {
                 f = Py_BuildValue("{s:s,s:u}", "Type", "TEXT", "Value", s);
                 free(s);
                 break;
+            case TODO_LOCATION:
+                s = strGammuToPython(entry->Entries[i].Text);
+                if (s == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:u}", "Type", "LOCATION", "Value", s);
+                free(s);
+                break;
+            case TODO_DESCRIPTION:
+                s = strGammuToPython(entry->Entries[i].Text);
+                if (s == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:u}", "Type", "DESCRIPTION", "Value", s);
+                free(s);
+                break;
+            case TODO_LUID:
+                s = strGammuToPython(entry->Entries[i].Text);
+                if (s == NULL) {
+                    Py_DECREF(v);
+                    return NULL;
+                }
+                f = Py_BuildValue("{s:s,s:u}", "Type", "LUID", "Value", s);
+                free(s);
+                break;
             case TODO_COMPLETED:
                 f = Py_BuildValue("{s:s,s:i}", "Type", "COMPLETED", "Value", entry->Entries[i].Number);
                 break;
@@ -154,12 +182,21 @@ PyObject *TodoToPython(const GSM_ToDoEntry *entry) {
         return NULL;
     }
 
-    r = Py_BuildValue("{s:i,s:s,s:O}",
+    t = CalendarTypeToString(entry->Type);
+    if (t == NULL) {
+        free(p);
+        Py_DECREF(v);
+        return NULL;
+    }
+
+    r = Py_BuildValue("{s:i,s:s,s:s,s:O}",
             "Location", entry->Location,
+            "Type", t,
             "Priority", p,
             "Entries", v
             );
     free(p);
+    free(t);
     Py_DECREF(v);
     return r;
 }
@@ -170,6 +207,7 @@ int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location) {
     int             len;
     int             i;
     char            *p;
+    char            *t;
     char            *type;
     char            valuetype;
 
@@ -185,6 +223,11 @@ int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location) {
         if (entry->Location == INT_INVALID) return 0;
     }
 
+    t = GetCharFromDict(dict, "Type");
+    if (t == NULL) return 0;
+    entry->Type = StringToCalendarType(t);
+    if (entry->Type == 0) return 0;
+
     p = GetCharFromDict(dict, "Priority");
     if (p == NULL) return 0;
     entry->Priority = StringToTodoPriority(p);
@@ -230,6 +273,15 @@ int TodoFromPython(PyObject *dict, GSM_ToDoEntry *entry, int needs_location) {
         } else if (strcmp("SILENT_ALARM_DATETIME", type) == 0) {
             valuetype = 'd';
             entry->Entries[i].EntryType = TODO_SILENT_ALARM_DATETIME;
+        } else if (strcmp("LUID", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = TODO_LUID;
+        } else if (strcmp("LOCATION", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = TODO_LOCATION;
+        } else if (strcmp("DESCRIPTION", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = TODO_DESCRIPTION;
         } else if (strcmp("TEXT", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = TODO_TEXT;
