@@ -163,38 +163,62 @@ int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
 }
 
 #define CREATE_ERROR(x) \
-    Py##x = PyErr_NewException("gammu." #x, GammuError, NULL);\
+    /* Help text */ \
+    help_text = PyString_FromFormat("Exception corresponding to gammu error " #x ".\nVerbose error description: %s", print_error(x, NULL, 0)); \
+    if (help_text == NULL) \
+        return 0; \
+    error_dict = PyDict_New(); \
+    if (error_dict == NULL) \
+        return 0; \
+    PyDict_SetItemString(error_dict, "__doc__", help_text); \
+    Py_DECREF(help_text); \
+    /* Create exception */ \
+    Py##x = PyErr_NewException("gammu." #x, GammuError, error_dict);\
+    Py_DECREF(error_dict); \
     if (Py##x == NULL)\
         return 0;\
-    help_text = PyString_FromFormat("Exception corresponding to gammu error " #x ".\nVerbose error description: %s", print_error(x, NULL, 0)); \
-    PyObject_SetAttrString(Py##x, "__doc__", help_text); \
-    Py_DECREF(help_text); \
     PyDict_SetItemString(d, "" #x, Py##x); \
     Py_DECREF(Py##x); \
+    /* Store ids in dict */ \
     id = PyInt_FromLong(x); \
     if (id == NULL)\
         return 0;\
     PyDict_SetItemString(error_list, "" #x, id); \
+    PyDict_SetItem(errornumber_list, id, PyString_FromString("" #x)); \
     Py_DECREF(id); \
     /* End of macro */
 
 
 int gammu_create_errors(PyObject *d) {
     PyObject *help_text;
+    PyObject *error_dict;
     PyObject *error_list;
+    PyObject *errornumber_list;
     PyObject *id;
 
     /* Prepare dict for error codes */
     error_list = PyDict_New();
     if (error_list == NULL)
         return 0;
+    errornumber_list = PyDict_New();
+    if (errornumber_list == NULL)
+        return 0;
 
-    GammuError = PyErr_NewException("gammu.GSMError", NULL, NULL);
+    /* Help text */
+    help_text = PyString_FromString("Generic class as parent for all gammu exceptions. This is never raised directly.");
+    if (help_text == NULL)
+        return 0;
+    error_dict = PyDict_New();
+    if (error_dict == NULL)
+        return 0;
+    PyDict_SetItemString(error_dict, "__doc__", help_text);
+    Py_DECREF(help_text);
+
+    /* Create exception */
+    GammuError = PyErr_NewException("gammu.GSMError", NULL, error_dict);
+    Py_DECREF(error_dict);
     if (GammuError == NULL)
         return 0;
-    help_text = PyString_FromString("Generic class as parent for all gammu exceptions. This is never raised directly.");
-    PyObject_SetAttrString(GammuError, "__doc__", help_text);
-    Py_DECREF(help_text);
     PyDict_SetItemString(d, "GSMError", GammuError);
     Py_DECREF(GammuError);
 
@@ -254,5 +278,8 @@ int gammu_create_errors(PyObject *d) {
     PyDict_SetItemString(d, "Errors", error_list);
     Py_DECREF(error_list);
 
+    PyDict_SetItemString(d, "ErrorNumbers", errornumber_list);
+    Py_DECREF(errornumber_list);
+
     return 1;
 }
